SWDEV-1 - Clean-up map file in Linux

Change-Id: Ibfad648c8ec9897a0895057c501d383875e95730
This commit is contained in:
German
2022-11-22 10:44:44 -05:00
committed by German Andryeyev
parent 33cb388101
commit 4471ed1210
2 changed files with 6 additions and 50 deletions
+6 -7
View File
@@ -261,13 +261,6 @@ global:
hipTexObjectGetResourceDesc;
hipTexObjectGetResourceViewDesc;
hipTexObjectGetTextureDesc;
extern "C++" {
hip_impl::hipLaunchKernelGGLImpl*;
hip_impl::demangle*;
hipCreateSurfaceObject*;
hipDestroySurfaceObject*;
hipHccModuleLaunchKernel*;
hipExtModuleLaunchKernel*;
hipGetCmdName*;
hipExtStreamCreateWithCUMask;
hipStreamGetPriority;
@@ -278,6 +271,12 @@ global:
hipMemcpyParam2DAsync;
__hipGetPCH;
hipExtStreamGetCUMask;
extern "C++" {
hipCreateSurfaceObject*;
hipDestroySurfaceObject*;
hipHccModuleLaunchKernel*;
hipExtModuleLaunchKernel*;
};
local:
*;
-43
View File
@@ -564,49 +564,6 @@ hipError_t hipOccupancyMaxActiveBlocksPerMultiprocessorWithFlags(int* numBlocks,
}
}
#if defined(ATI_OS_LINUX)
namespace hip_impl {
void hipLaunchKernelGGLImpl(uintptr_t function_address, const dim3& numBlocks,
const dim3& dimBlocks, uint32_t sharedMemBytes, hipStream_t stream,
void** kernarg) {
HIP_INIT_VOID();
hip::Stream* s = reinterpret_cast<hip::Stream*>(stream);
int deviceId = (s != nullptr) ? s->DeviceId() : ihipGetDevice();
if (deviceId == -1) {
LogPrintfError("Wrong Device Id: %d \n", deviceId);
}
hipFunction_t func = nullptr;
hipError_t hip_error = PlatformState::instance().getStatFunc(
&func, reinterpret_cast<void*>(function_address), deviceId);
if ((hip_error != hipSuccess) || (func == nullptr)) {
LogPrintfError("Cannot find the static function: 0x%x", function_address);
}
hip_error =
hipModuleLaunchKernel(func, numBlocks.x, numBlocks.y, numBlocks.z, dimBlocks.x, dimBlocks.y,
dimBlocks.z, sharedMemBytes, stream, nullptr, kernarg);
assert(hip_error == hipSuccess);
}
void hipLaunchCooperativeKernelGGLImpl(uintptr_t function_address, const dim3& numBlocks,
const dim3& dimBlocks, uint32_t sharedMemBytes,
hipStream_t stream, void** kernarg) {
HIP_INIT_VOID();
hipError_t err = hipLaunchCooperativeKernel(reinterpret_cast<void*>(function_address), numBlocks,
dimBlocks, kernarg, sharedMemBytes, stream);
assert(err == hipSuccess);
}
} // namespace hip_impl
#endif // defined(ATI_OS_LINUX)
hipError_t ihipLaunchKernel(const void* hostFunction, dim3 gridDim, dim3 blockDim, void** args,
size_t sharedMemBytes, hipStream_t stream, hipEvent_t startEvent,
hipEvent_t stopEvent, int flags) {